@@ -3,7 +3,7 @@ use object::PyObject;
 
 pub const PY_STDIOTEXTMODE : &'static str = "b";
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyFile_FromFd(arg1: c_int, arg2: *const c_char,
                          arg3: *const c_char, arg4: c_int,
                          arg5: *const c_char,
@@ -18,6 +18,8 @@ extern "C" {
                               arg2: *mut PyObject) -> c_int;
                               
     pub static mut Py_FileSystemDefaultEncoding: *const c_char;
+    #[cfg(Py_3_6)]
+    pub static mut Py_FileSystemDefaultEncodeErrors: *const c_char;
     pub static mut Py_HasFileSystemDefaultEncoding: c_int;
 }
 
