@@ -1,7 +1,7 @@
 use libc::c_int;
 
 #[cfg(not(Py_LIMITED_API))]
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub static mut Py_DebugFlag: c_int;
     pub static mut Py_VerboseFlag: c_int;
     pub static mut Py_QuietFlag: c_int;
@@ -19,5 +19,7 @@ extern "C" {
     pub static mut Py_HashRandomizationFlag: c_int;
     #[cfg(Py_3_4)]
     pub static mut Py_IsolatedFlag: c_int;
+    #[cfg(all(Py_3_6, windows))]
+    pub static mut Py_LegacyWindowsStdioFlag: c_int;
 }
 
