@@ -2,21 +2,24 @@ use libc::{c_int, c_long};
 use object::PyObject;
 use moduleobject::PyModuleDef;
 
+#[cfg(Py_3_6)]
+pub const MAX_CO_EXTRA_USERS: c_int = 255;
+
 pub enum PyInterpreterState { }
 pub enum PyThreadState { }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyInterpreterState_New() -> *mut PyInterpreterState;
     pub fn PyInterpreterState_Clear(arg1: *mut PyInterpreterState) -> ();
     pub fn PyInterpreterState_Delete(arg1: *mut PyInterpreterState) -> ();
-    fn _PyState_AddModule(arg1: *mut PyObject,
-                              arg2: *mut PyModuleDef) -> c_int;
+    //fn _PyState_AddModule(arg1: *mut PyObject,
+    //                      arg2: *mut PyModuleDef) -> c_int;
     pub fn PyState_FindModule(arg1: *mut PyModuleDef) -> *mut PyObject;
     pub fn PyThreadState_New(arg1: *mut PyInterpreterState)
      -> *mut PyThreadState;
-    fn _PyThreadState_Prealloc(arg1: *mut PyInterpreterState)
-     -> *mut PyThreadState;
-    pub fn _PyThreadState_Init(arg1: *mut PyThreadState) -> ();
+    //fn _PyThreadState_Prealloc(arg1: *mut PyInterpreterState)
+    // -> *mut PyThreadState;
+    //fn _PyThreadState_Init(arg1: *mut PyThreadState) -> ();
     pub fn PyThreadState_Clear(arg1: *mut PyThreadState) -> ();
     pub fn PyThreadState_Delete(arg1: *mut PyThreadState) -> ();
     #[cfg(py_sys_config="WITH_THREAD")]
@@ -35,7 +38,7 @@ pub enum PyGILState_STATE {
     PyGILState_UNLOCKED
 }
 
-extern "C" {
+#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
     pub fn PyGILState_Ensure() -> PyGILState_STATE;
     pub fn PyGILState_Release(arg1: PyGILState_STATE) -> ();
     pub fn PyGILState_GetThisThreadState() -> *mut PyThreadState;
